@@ -1,11 +1,12 @@
 package Finance::Bank::ID::BCA;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.38'; # VERSION
+
 use 5.010001;
 use Moo;
 use DateTime;
-use Log::Any '$log';
-
-our $VERSION = '0.37'; # VERSION
+use Log::Any::IfLOG '$log';
 
 extends 'Finance::Bank::ID::Base';
 
@@ -447,7 +448,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.37 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-06-09.
+This document describes version 0.38 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -726,7 +727,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BCA>.
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BCA>.
 
 =head1 BUGS
 
