@@ -1,11 +1,11 @@
 package Finance::Bank::ID::Base;
 
-our $DATE = '2015-06-09'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010;
 use Moo;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Dumper;
 use Data::Rmap qw(:all);
@@ -19,9 +19,9 @@ has password    => (is => 'rw');
 has logged_in   => (is => 'rw');
 has accounts    => (is => 'rw');
 has logger      => (is => 'rw',
-                    default => sub { Log::Any->get_logger() } );
+                    default => sub { Log::Any::IfLOG->get_logger() } );
 has logger_dump => (is => 'rw',
-                    default => sub { Log::Any->get_logger() } );
+                    default => sub { Log::Any::IfLOG->get_logger() } );
 
 has site => (is => 'rw');
 
@@ -277,7 +277,7 @@ Finance::Bank::ID::Base - Base class for Finance::Bank::ID::BCA etc
 
 =head1 VERSION
 
-This document describes version 0.37 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-06-09.
+This document describes version 0.38 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -371,7 +371,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BCA>.
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BCA>.
 
 =head1 BUGS
 
