@@ -1,12 +1,12 @@
 package Finance::BankUtils::ID::Mechanize;
 
-our $DATE = '2015-06-09'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use parent qw(WWW::Mechanize);
 
@@ -64,7 +64,7 @@ Finance::BankUtils::ID::Mechanize - A subclass of WWW::Mechanize
 
 =head1 VERSION
 
-This document describes version 0.37 of Finance::BankUtils::ID::Mechanize (from Perl distribution Finance-Bank-ID-BCA), released on 2015-06-09.
+This document describes version 0.38 of Finance::BankUtils::ID::Mechanize (from Perl distribution Finance-Bank-ID-BCA), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BCA>.
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BCA>.
 
 =head1 BUGS
 
